Building the bact archiver package
==================================
This packages implements the protobuf based access to the archiver
appliance. This packages contains:

* In directory `proto`

    * the protocol definition
    * cython files for the access


* In directory `proto_gen`

    * the files generated by the protoc compiler, as long as these
      need to be compiled (i.e. c++ source and header files)


 So a typical build process adheres to standard package interface

Budiling protocol buffer files
------------------------------

A custom command is provided for the protoc compile step. Please use

.. code::python

   python3 setup.py build_proto_c


for this step. This step is typically required to keep track with the locally
used protobuf implementation. A following build will cythonize and
compile the generated files.
